@@ -628,6 +628,17 @@ class Client:
 
     # Ingesting transform frames
 
+    @handle_agent_exceptions
+    def set_base_frame_id(
+        self, base_reference_frame  # type: str
+    ):
+        """
+        Sets the base reference frame for tf tree ingestion
+        """
+        self.agent_stub.SetBaseFrameID(
+            agent_pb2.SetBaseFrameIDRequest(id=base_reference_frame)
+        )
+
     @handle_agent_exceptions
     def post_transform_frame(
         self,
