@@ -4,7 +4,9 @@ from .transform import Transform
 
 class Goal:
     def __init__(
-        self, pose: Transform = Transform(), transform_to_world: Transform = Transform()
+        self,
+        pose=Transform(),  # type: Transform
+        transform_to_world=Transform(),  # type: Transform
     ):
         self.pose = pose
         self.transform_to_world = transform_to_world
