@@ -6,7 +6,8 @@ from formant.protos.model.v1.media_pb2 import PointCloud
 import numpy as np
 
 
-def laserscan_to_formant_pointcloud(message) -> PointCloud:
+def laserscan_to_formant_pointcloud(message):
+    # type (...) -> PointCloud
     height = 1
     width = len(message.ranges)
     count = height * width
