@@ -11,11 +11,18 @@ class Quaternion:
         return cls(quaternion.x, quaternion.y, quaternion.z, quaternion.w)
 
     @classmethod
-    def from_direction(cls, direction: float):
+    def from_direction(
+        cls, direction  # type: float
+    ):
         return cls.from_euler(0, 0, direction)
 
     @classmethod
-    def from_euler(cls, roll: float, pitch: float, yaw: float):
+    def from_euler(
+        cls,
+        roll,  # type: float
+        pitch,  # type: float
+        yaw,  # type: float
+    ):
         [x, y, z, w] = get_quaternion_from_euler(roll, pitch, yaw)
         return cls(x, y, z, w)
 
@@ -23,7 +30,13 @@ class Quaternion:
     def identity(cls):
         return cls(0, 0, 0, 1)
 
-    def __init__(self, x: float, y: float, z: float, w: float):
+    def __init__(
+        self,
+        x,  # type: float
+        y,  # type: float
+        z,  # type: float
+        w,  # type: float
+    ):
         self.x = x
         self.y = y
         self.z = z
