@@ -553,8 +553,10 @@ class Client:
         message=None,  # type:str
         keyword=None,  # type: str
         end_time=datetime.datetime.now(tz=tzutc()),  # type: datetime.datetime
-        params={},  # type: Dict
+        params=None,  # type: Dict
     ):
+        params = params if params is not None else {}
+
         params["tags"] = tags
         params["start"] = start_time.isoformat()
         params["end"] = end_time.isoformat()
